# createTestReport

```create_test_report.[bat|sh]``` executes the tests in ```./tests``` with pytest. It will generate the test report in HTML and XML format.

The XML test report will be then converted to TRLC.

The TRLC test report will be then converted to Markdown and reStructuredText format.

![createTestReport](https://www.plantuml.com/plantuml/proxy?cache=no&src=https://raw.githubusercontent.com/NewTec-GmbH/pyTRLCConverter/refs/heads/main/doc/architecture/create_test_report.puml)
